==> patternfly-java-components-0.3.0.jar: org/patternfly/component/expandable/ExpandableSectionContent.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.component.expandable;

import org.jboss.elemento.ElementTextMethods;
import org.jboss.elemento.Id;
import org.patternfly.component.ComponentType;

import elemental2.dom.HTMLDivElement;

import static org.jboss.elemento.Elements.div;
import static org.patternfly.core.Attributes.role;
import static org.patternfly.core.Roles.region;
import static org.patternfly.style.Classes.component;
import static org.patternfly.style.Classes.content;
import static org.patternfly.style.Classes.expandableSection;

public class ExpandableSectionContent extends ExpandableSectionSubComponent<HTMLDivElement, ExpandableSectionContent> implements
        ElementTextMethods<HTMLDivElement, ExpandableSectionContent> {

    // ------------------------------------------------------ factory

    public static ExpandableSectionContent expandableSectionContent() {
        return new ExpandableSectionContent();
    }

    // ------------------------------------------------------ instance

    static final String SUB_COMPONENT_NAME = "esc";

    final String id;

    ExpandableSectionContent() {
        super(SUB_COMPONENT_NAME, div().css(component(expandableSection, content))
                .apply(e -> e.hidden = true)
                .attr(role, region)
                .element());

        id(this.id = Id.unique(ComponentType.ExpandableSection.id, "cnt"));
    }

    // ------------------------------------------------------ builder

    @Override
    public ExpandableSectionContent that() {
        return this;
    }
}

==> patternfly-java-components-0.3.1.jar: org/patternfly/component/expandable/ExpandableSectionContent.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.component.expandable;

import org.jboss.elemento.ElementTextMethods;
import org.jboss.elemento.Id;
import org.patternfly.component.ComponentType;

import elemental2.dom.HTMLDivElement;

import static org.jboss.elemento.Elements.div;
import static org.patternfly.core.Attributes.role;
import static org.patternfly.core.Roles.region;
import static org.patternfly.style.Classes.component;
import static org.patternfly.style.Classes.content;
import static org.patternfly.style.Classes.expandableSection;

public class ExpandableSectionContent extends ExpandableSectionSubComponent<HTMLDivElement, ExpandableSectionContent> implements
        ElementTextMethods<HTMLDivElement, ExpandableSectionContent> {

    // ------------------------------------------------------ factory

    public static ExpandableSectionContent expandableSectionContent() {
        return new ExpandableSectionContent();
    }

    // ------------------------------------------------------ instance

    public static final String SUB_COMPONENT_NAME = "esc";

    final String id;

    ExpandableSectionContent() {
        super(SUB_COMPONENT_NAME, div().css(component(expandableSection, content))
                .apply(e -> e.hidden = true)
                .attr(role, region)
                .element());

        id(this.id = Id.unique(ComponentType.ExpandableSection.id, "cnt"));
    }

    // ------------------------------------------------------ builder

    @Override
    public ExpandableSectionContent that() {
        return this;
    }
}
